summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Smith <tsmith@chef.io>2021-06-11 08:43:15 -0700
committerTim Smith <tsmith@chef.io>2021-06-11 08:43:15 -0700
commit4d69c496c4ac1900f3febccbee4867f36fc112a1 (patch)
tree351093c2ac74de93af0865286451ee4f862c7e21
parent7be0f348cdbf0ee6a40403e97e8d85ef85d928f9 (diff)
downloadchef-4d69c496c4ac1900f3febccbee4867f36fc112a1.tar.gz
Minor improvements for our self documented resources
Improve the content we generate Signed-off-by: Tim Smith <tsmith@chef.io>
-rw-r--r--lib/chef/resource/dsc_resource.rb2
-rw-r--r--lib/chef/resource/execute.rb6
2 files changed, 4 insertions, 4 deletions
diff --git a/lib/chef/resource/dsc_resource.rb b/lib/chef/resource/dsc_resource.rb
index 679deef47b..a869e2acc4 100644
--- a/lib/chef/resource/dsc_resource.rb
+++ b/lib/chef/resource/dsc_resource.rb
@@ -74,7 +74,7 @@ class Chef
property :module_version, String,
introduced: "12.21",
- description: "The version number of the module to use. PowerShell 5.0.10018.0 (or higher) supports having multiple versions of a module installed. This should be specified along with the module_name."
+ description: "The version number of the module to use. PowerShell 5.0.10018.0 (or higher) supports having multiple versions of a module installed. This should be specified along with the `module_name` property."
def property(property_name, value = nil)
unless property_name.is_a?(Symbol)
diff --git a/lib/chef/resource/execute.rb b/lib/chef/resource/execute.rb
index b830f119be..1f7e1b2c1b 100644
--- a/lib/chef/resource/execute.rb
+++ b/lib/chef/resource/execute.rb
@@ -304,9 +304,9 @@ class Chef
gives a recipe full control over the command issued in a much cleaner, more
direct manner.
- **Use the search recipe DSL method to find users**:
+ **Use the search Infra Language helper to find users**:
- The following example shows how to use the `search` method in the Recipe DSL to
+ The following example shows how to use the `search` method in the Chef Infra Language to
search for users:
```ruby
@@ -515,7 +515,7 @@ class Chef
property :command, [ String, Array ],
name_property: true,
- description: "An optional property to set the command to be executed if it differs from the resource block's name."
+ description: "An optional property to set the command to be executed if it differs from the resource block's name. Note: Use the **execute** resource to run a single command. Use multiple **execute** resource blocks to run multiple commands."
property :umask, [ String, Integer ],
description: "The file mode creation mask, or umask."